@@ -41,7 +41,7 @@ class AccessPolicy(permissions.BasePermission):
             the name of the function.
         """
         if hasattr(view, "action"):
-            return view.action
+            return view.action or list(view.action_map.values())[0]
         elif hasattr(view, "__class__"):
             return view.__class__.__name__
         raise AccessPolicyException("Could not determine action of request")
